@@ -4,7 +4,7 @@ import glob
 from firstimpression import file
 
 from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, ENGLISH_INDEX, DUTCH_INDEX
-from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files, download_install_media, list_files_dir
+from firstimpression.file import update_directories_api, check_too_old, write_root_to_xml_files, download_install_media, list_files_dir, xml_to_root
 from firstimpression.time import change_language, parse_string_to_string
 from firstimpression.text import remove_emoji
 from firstimpression.scala import variables, Log
@@ -34,17 +34,14 @@ LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME)
 URL = 'https://fi-api.io/instagram_post/'
 BASE_URL_IMAGES = 'https://socials-bucket.s3.eu-central-1.amazonaws.com'
 
-XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, 'instagram.xml')
-
 ##################################################################################################
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, max_minutes, max_characters, max_items, language):
+def run_api(api_key, max_minutes, max_characters, max_items, language, tags):
 
     debug.log('folder name: {}'.format(NAME))
-    debug.log('file path temp: {} - local: {}'.format(XML_TEMP_PATH, LOCAL_PATH))
-    
+        
     max_file_age = 60 * max_minutes
 
     debug.log('max_file_age: {}'.format(max_file_age))
@@ -64,48 +61,48 @@ def run_api(api_key, max_minutes, max_characters, max_items, language):
         'Authorization': 'Token {}'.format(api_key)
     }
 
+    tags = tags.split(';')
+
     update_directories_api(NAME)
 
     params = {
         'number_of_posts': max_items
     }
 
-    if check_too_old(XML_TEMP_PATH, max_file_age):
-        response_json = request_json(URL, headers, params, False)
-
+    for tag in tags:
         root = ET.Element("root")
+        if not (tag is None or tag == ''):
+            params['tag'] = tag
+            xml_temp_path = os.path.join(TEMP_FOLDER, NAME, 'instagram_{}.xml'.format(tag))
+        else:
+            params.pop('tag', None)
+            xml_temp_path = os.path.join(TEMP_FOLDER, NAME, 'instagram.xml')
+        
+        debug.log('file path temp: {} - local: {}'.format(xml_temp_path, LOCAL_PATH))
+        
+        if check_too_old(xml_temp_path, max_file_age):
 
-        for post in response_json:
-            item = ET.SubElement(root, "item")
-            ET.SubElement(item, "likes").text = str(get_likes(post))
-            ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters, language_index)
-            ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, datetime_format_new)
+            response_json = request_json(URL, headers, params, False)
 
-            thumbnail_url = get_media(post)
-            if thumbnail_url is None:
-                debug.log('image not found so using placeholder')
-                media_link = 'Content:\\placeholders\\img.png'
-            else:
-                media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
-            
-            ET.SubElement(item, "media").text = media_link
-
-            if media_link.endswith("mp4"):
-                ET.SubElement(item, "media_type").text = "video"
-            else:
-                ET.SubElement(item, "media_type").text = "image"
-
-        write_root_to_xml_files(root, XML_TEMP_PATH, NAME)        
-    else:
-        debug.log('File not old enough to update')
-def check_api(max_minutes):
+            for post in response_json:
+                root.append(parse_post(post, max_characters, language_index, datetime_format_new))
+    
+            write_root_to_xml_files(root, xml_temp_path, NAME)
+        else:
+            debug.log('File not old enough')      
+    
+def check_api(max_minutes, tag, min_items):
     svars = variables()
 
     max_file_age = 60 * max_minutes
 
     debug.log('max_file_age: {}'.format(max_file_age))
 
-    file_name = 'instagram*.xml'.format()
+    if tag is '' or tag is None:
+        file_name = 'instagram[*.xml'
+    else:
+        file_name = 'instagram_{}*.xml'.format(tag)
+
     file_path = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, file_name)
 
     debug.log('local path: {}'.format(file_path))
@@ -121,6 +118,11 @@ def check_api(max_minutes):
             info.log('file too old')
         else:
             svars['skipscript'] = False
+            amount_items = len(xml_to_root(file_path))
+
+            if amount_items < min_items:
+                svars['skipscript'] = True
+                info.log('{} has to less post to show'.format(tag))
     else:
         warn.log('File does not exists')
         svars['skipscript'] = True
@@ -150,10 +152,6 @@ def get_likes(post):
     return post.get('likes', 0)
 
 
-def get_hashtags(post):
-    hashtags = post.get('hashtags', [''])
-    return ' '.join(hashtags)
-
 ##################################################################################################
 # PARSE FUNCTIONS
 ##################################################################################################
@@ -170,4 +168,25 @@ def crop_message(text, max_length, language):
         return text
 
 
+def parse_post(post, max_characters, language_index, datetime_format_new):
+    item = ET.Element("item")
+    ET.SubElement(item, "likes").text = str(get_likes(post))
+    ET.SubElement(item, "message").text = crop_message(remove_emoji(get_message(post)), max_characters, language_index)
+    ET.SubElement(item, "created_time").text = parse_string_to_string(get_creation_date(post), DATETIME_FORMAT, datetime_format_new)
+
+    thumbnail_url = get_media(post)
+    if thumbnail_url is None:
+        debug.log('image not found so using placeholder')
+        media_link = 'Content:\\placeholders\\img.png'
+    else:
+        media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
+    
+    ET.SubElement(item, "media").text = media_link
+
+    if media_link.endswith("mp4"):
+        ET.SubElement(item, "media_type").text = "video"
+    else:
+        ET.SubElement(item, "media_type").text = "image"
+    
+    return item
 
