@@ -265,7 +265,7 @@ def install_content(abspath, subfolder=None):
     try:
         netic = win32com.client.Dispatch(_prog_id_netic)
         netic.IntegrateContentLocally(abspath, subfolder)
-        log(logging.INFO, abspath)
+        # log(logging.INFO, abspath)
 
         if subfolder:
             where_it_should_be = 'Content://' + \
@@ -303,7 +303,7 @@ def _lock_content(scalapath, report_err=True):
 
         def __del__(self):
             if hasattr(self, 'lockObj'):
-                log(logging.DEBUG, 'unlock_content: "{}"'.format(scalapath))
+                # log(logging.DEBUG, 'unlock_content: "{}"'.format(scalapath))
                 self.lockObj.UnlockScalaFile()
 
     try:
@@ -314,7 +314,7 @@ def _lock_content(scalapath, report_err=True):
         windows_path = _StringAndLock(windows_path)
         windows_path.lockObj = lockObj
 
-        log(logging.INFO, '"{}" @ "{}"'.format(scalapath, windows_path))
+        # log(logging.INFO, '"{}" @ "{}"'.format(scalapath, windows_path))
 
         return windows_path
     except Exception as err:
@@ -474,7 +474,12 @@ class Log:
         self.level = NAMELEVEL[name]
         self.script = script
         try:
-            self.debug = variables()['Player.debug_python']
+            svars = variables()
+            found = False
+            for var in svars:
+                if var == 'Player.debug_python':
+                    found = True
+            self.debug = found
         except KeyError:
             self.debug = False
     
